import { useEffect } from "react";
import { ErrorBoundary } from "react-error-boundary";
import { Route, Router, Switch } from "wouter";
import { useLocation } from "wouter";
import { AnimatePresence } from "framer-motion";
// import { useToast } from "@/hooks/use-toast";
import PageTransition from "@/components/layout/PageTransition";
import SEOHead from "@/components/seo/SEOHead";
import EnquiryPopup, { EnquiryFormData } from "@/components/ui/EnquiryPopup";
import { useEnquiryPopup } from "@/hooks/useEnquiryPopup";
import Home from "@/pages/Home";
import About from "./pages/About";
import AboutUs from "./pages/AboutUs";
import Products from "./pages/Products";
import Contact from "./pages/Contact";
import News from "./pages/News";
import VideoPlayer from "./pages/VideoPlayer";
import Finance from "./pages/Finance";
import PartnerProgram from "./pages/PartnerProgram";
import TestDrive from "./pages/TestDrive";
import ProductBrochure from "./pages/ProductBrochure";
import AdminLogin from "./pages/AdminLogin";
import AdminDashboard from "./pages/AdminDashboard";
import DealerAuth from "./pages/DealerAuth";
import DealerDashboard from "./pages/DealerDashboard";
import AdminDealerApproval from "./pages/AdminDealerApproval";
import BrochureRequests from "./pages/BrochureRequests";
import PartnerInquiriesAdmin from "./pages/PartnerInquiriesAdmin";
import SalesSupport from "./pages/SalesSupport";
import ServiceSupport from "./pages/ServiceSupport";
import NotFound from "./pages/not-found";
import PrivacyPolicy from "./pages/PrivacyPolicy";
import RefundPolicy from "./pages/RefundPolicy";
import TermsOfService from "./pages/TermsOfService";
import CookiePolicy from "./pages/CookiePolicy";
import ConnectNow from "./pages/ConnectNow";
import Support from "./pages/Support";

function AppRouter() {
  const [location] = useLocation();

  useEffect(() => {
    window.scrollTo(0, 0);
  }, [location]);

  return (
    <AnimatePresence mode="wait">
      <Switch>
        <Route path="/">
          <PageTransition>
            <Home />
          </PageTransition>
        </Route>
        <Route path="/about">
          <PageTransition>
            <About />
          </PageTransition>
        </Route>
         <Route path="/about-us">
          <PageTransition>
            <AboutUs />
          </PageTransition>
        </Route>
        <Route path="/products">
          <PageTransition>
            <Products />
          </PageTransition>
        </Route>
        <Route path="/finance">
          <PageTransition>
            <Finance />
          </PageTransition>
        </Route>
        <Route path="/news">
          <PageTransition>
            <News />
          </PageTransition>
        </Route>
        <Route path="/contact">
          <PageTransition>
            <Contact />
          </PageTransition>
        </Route>
        <Route path="/dealer-login">
          <PageTransition>
            <DealerAuth />
          </PageTransition>
        </Route>
        <Route path="/admin/brochure-requests">
          <PageTransition>
            <BrochureRequests />
          </PageTransition>
        </Route>
        <Route path="/admin/dealers">
          <PageTransition>
            <AdminDealerApproval />
          </PageTransition>
        </Route>
        <Route path="/dealer/dashboard">
          <PageTransition>
            <DealerDashboard />
          </PageTransition>
        </Route>
        <Route path="/refund-policy">
          <PageTransition>
            <RefundPolicy />
          </PageTransition>
        </Route>
         <Route path="/privacy-policy">
          <PageTransition>
            <PrivacyPolicy />
          </PageTransition>
        </Route>
        <Route path="/support">
          <PageTransition>
            <Support />
          </PageTransition>
        </Route>
        <Route path="/sales-support">
          <PageTransition>
            <Support />
          </PageTransition>
        </Route>
        <Route path="/service-support">
          <PageTransition>
            <Support />
          </PageTransition>
        </Route>
        <Route path="/test-drive">
          <PageTransition>
            <TestDrive />
          </PageTransition>
        </Route>

        <Route path="/admin/test-email">
          <PageTransition>
            <NotFound />
          </PageTransition>
        </Route>
        <Route path="/admin/email-setup">
          <PageTransition>
            <NotFound />
          </PageTransition>
        </Route>
        <Route path="/lxg-secure-admin-portal">
          <PageTransition>
            <AdminLogin />
          </PageTransition>
        </Route>
        <Route path="/admin/dashboard">
          <PageTransition>
            <AdminDashboard />
          </PageTransition>
        </Route>
        <Route path="/admin/leads">
          <PageTransition>
            <AdminDashboard />
          </PageTransition>
        </Route>
         <Route path="/terms-of-service">
          <PageTransition>
            <TermsOfService />
          </PageTransition>
        </Route>
        <Route path="/cookie-policy">
          <PageTransition>
            <CookiePolicy />
          </PageTransition>
        </Route>
        <Route path="/secure/:token">
          <PageTransition>
            <NotFound />
          </PageTransition>
        </Route>
        <Route path="/admin/partner-inquiries">
          <PageTransition>
            <PartnerInquiriesAdmin />
          </PageTransition>
        </Route>
         <Route path="/product-brochure">
          <PageTransition>
            <ProductBrochure />
          </PageTransition>
        </Route>
        <Route path="/partner-program">
          <PageTransition>
            <PartnerProgram />
          </PageTransition>
        </Route>
        <Route path="/connect-now">
          <PageTransition>
            <ConnectNow />
          </PageTransition>
        </Route>
        <Route path="/news/:id">
          <PageTransition>
            <News />
          </PageTransition>
        </Route>
                <Route path="/video/:videoId">
          <PageTransition>
            <VideoPlayer />
          </PageTransition>
        </Route>
        <Route>
          <PageTransition>
            <NotFound />
          </PageTransition>
        </Route>
      </Switch>
    </AnimatePresence>
  );
}



function App() {
  const { isOpen, closePopup } = useEnquiryPopup();

  const handleEnquirySubmit = async (data: EnquiryFormData) => {
    try {
      const response = await fetch('/api/enquiry', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify(data),
      });

      const result = await response.json();

      if (response.ok) {
        alert(result.message || 'Enquiry submitted successfully! Our team will contact you soon.');
      } else {
        alert(result.error || 'Failed to submit enquiry');
      }
    } catch (error) {
      console.error('Error submitting enquiry:', error);
      alert('Failed to submit enquiry. Please try again.');
    }
  };

  return (
    <div className="transition-all duration-300 ease-in-out">
      <AppRouter />
      
      {/* Enquiry Popup - Rendered at top level for proper overlay */}
      <EnquiryPopup
        isOpen={isOpen}
        onClose={closePopup}
        onSubmit={handleEnquirySubmit}
      />
    </div>
  );
}

export default App;